---
Summary: Have at least some accurate documentation
Status: Done
---

# Description

-   Generate some Sphinx docs
-   Write some docs
-   Make sure arguments are covered
-   Upload to readthedocs if possible
